//*****************************************************************************
//
//	InactivityTimer.h.  	
//
//	Tracks and determines whether inactivity timeout is warranted, also 
//	controls pppStats.
//
//		by	Felipe A. Rodriguez		
//
//	This code is supplied "as is" the author makes no warranty as to its 
//	suitability for any purpose.  This code is free and may be distributed 
//	in accordance with the terms of the:
//		
//			GNU GENERAL PUBLIC LICENSE
//			Version 2, June 1991
//			copyright (C) 1989, 1991 Free Software Foundation, Inc.
// 			675 Mass Ave, Cambridge, MA 02139, USA
//
//*****************************************************************************


#import "InactivityTimer.h"
#import "CommandScroll.h"
#import "Coordinator.h"

#import "pppstats.h"


@implementation InactivityTimer

//************************************************************************
//
// 		designated initializer
//
//************************************************************************
 
- init
{
	[super init];
						// setup inactivity timeout Instance var from ddb value
	timeout = atoi(NXGetDefaultValue([NXApp appName], "Timeout"));
	posNI = NO;								// set interactive session ivar
		
    return self;
}
//************************************************************************
//
// 		test for inactivity timeout
//
//************************************************************************
 
- inactivityTimeout
{											// Inactivity timeout algorithm
	if(pppstats)							// if pppstats is enabled
		{
		if(intpr())							// call pppstats measuring func
			iPeriodCntr++;					// cntr counts # of consecutive 
		else								// 0 ppp i/o intervals
			iPeriodCntr = 0;				// reset cntr if link is active
		iBaseCntr++;						// bCntr counts from time link up

		wasHidden =	[NXApp isHidden];		// is the app hidden?
					// if interface is inactive for > n min or non-interactive 	
					// session in progress and timeout "ON" and this is a 
					// possibly non-interactive session.
		if((iPeriodCntr > (timeout - 1) || ((iBaseCntr < 4) && 
						(iPeriodCntr > 0) && (posNI == YES))) && (timeout > 0))
			{
			[NXApp activateSelf:YES];								
			if(!ITPanel) 
				[NXApp loadNibSection:"InactivityPanel.nib" owner:self
											withNames:NO fromZone:[self zone]];
			[ITPanel center];
			[ITPanel makeKeyAndOrderFront:self];
			}
		}
		
    return self;
}
//*****************************************************************************
//
// 		set inactivity timeout Ivar and write its value to ddb 
//
//*****************************************************************************

- setTimeout:(int)minTillTimeout 
{
char buf[8];

	timeout = minTillTimeout;
	sprintf(buf,"%d",(int)timeout);
	if(!NXWriteDefault([NXApp appName], "Timeout", buf))
		NXRunAlertPanel(0, "Error setting defaults database", 0, 0, 0);	

	return self; 
}
//************************************************************************
//
// 		reset our Ivars
//
//************************************************************************
 
- resetInactivityTimer
{
	iPeriodCntr = 0;				// reset inactivity timeout cntr
	iBaseCntr = 0;					// reset inactivity timeout base counter
		
    return self;
}
//*****************************************************************************
//
// 		set when upcoming session is possibly not interactive, only DNS 
//			triggered sessions are given this status
//
//*****************************************************************************

- setPosNonInter:(BOOL)pni 
{
	posNI = pni;				// DNS triggered session, possibly 	
									// non-interactive 
	return self; 
}
//*****************************************************************************
//
// 		return whether session is possibly a DNS triggered non-interactive  
//
//*****************************************************************************

- (BOOL)posNonInter; 
{
	return posNI; 
}
//************************************************************************
//
// 		enable pppstats
//
//************************************************************************
 
- pppstats:aView
{
	commandView = aView;
	if(!pppstats)
		{									// display pppstats?
		if(strcmp(NXGetDefaultValue([NXApp appName], "DispPPP"),"YES") == 0)
			openSocket(aView);		// open IP datagram socket, pass a view
		else
			openSocket(nil);		// open IP datagram socket, w/o view
		pppstats = YES;	
		}				
		
	return self;
}
//************************************************************************
//
// 		disable pppstats
//
//************************************************************************
 
- pppstatsReset
{
	pppstats = NO;	
		
	return self;
}
//*****************************************************************************
//
// 		do not end ppp session 
//
//*****************************************************************************

- cancel:sender
{
	posNI = NO;				 	
	[sView removeTimedEntry];
	[ITPanel close];
	ITPanel = nil;			
	if(wasHidden)				// if app was hidden prior to cursor in, hide
		[NXApp hide:self];
	iPeriodCntr = 0;

	return self;
}
//*****************************************************************************
//
// 		end ppp session 
//
//*****************************************************************************

- continue:sender
{
	[sView removeTimedEntry];
	[ITPanel close];
	ITPanel = nil;			
					// unlink if unlink menu item is enabled + pppstats
	if([[[NXApp mainMenu] findCellWithTag:3] isEnabled])
		{
		[[NXApp delegate] UnLink:self];	
		if((iPeriodCntr > (timeout - 1)) && commandView)	
			[commandView appendStringUseFixedFont:
					"Link dropped due to inactivity timeout\n"];
		else
			[commandView appendStringUseFixedFont:
					"Link dropped due to non-interactive session\n"];
		if(wasHidden)		// if app was hidden prior to cursor in, hide
			[NXApp hide:self];
		}
	iPeriodCntr = 0;

	return self;
}


@end
